trame-leaflet
===========================================================================

trame-leaflet extends trame **widgets** with components from vue-leaflet.

This package is under the same MIT License as `Vue-Leaflet <https://github.com/vue-leaflet/Vue2Leaflet/blob/master/LICENSE>`_ which that library embeds.

Leaflet integration in trame allows you to create map views with useful widgets.


How to use it?
```````````````````````````````````````````````````````````

Using the Python library

.. code-block:: python

    from trame.widgets import leaflet
